@@ -19,7 +19,7 @@ package JSON::Schema::Helper;
 # TODO: {id}, {dependencies}
 
 use 5.010;
-use common::sense;
+use strict qw( vars subs );
 use constant FALSE => !1;
 use constant TRUE  => !!1;
 no autovivification;
@@ -30,7 +30,8 @@ use JSON::Schema::Null;
 use POSIX qw[modf];
 use Scalar::Util qw[blessed];
 
-our $VERSION = '0.012';
+our $AUTHORITY = 'cpan:TOBYINK';
+our $VERSION   = '0.013';
 
 sub new
 {
@@ -118,17 +119,12 @@ sub checkType
 #		and ($type eq 'null' ? $self->jsIsNull($value) : $self->jsMatchType($type, $value))
 #		and !(ref $value eq 'ARRAY' and $type eq 'array')
 #		and !($type eq 'integer' and $value % 1 == 0))
-		if (!$self->jsMatchType($type, $value))
-		{
-			$addError->($self->jsGuessType($value)." value found, but a $type is required");
-			return @E;
-		}
 		if (ref $type eq 'ARRAY')
 		{
 			my @unionErrors;
 			TYPE: foreach my $t (@$type)
 			{
-				@unionErrors = @{ $self->checkType($t, $value, $path, $_changing, $schema) };
+				@unionErrors = $self->checkType($t, $value, $path, $_changing, $schema);
 				last unless @unionErrors;
 			}
 			return @unionErrors if @unionErrors;
@@ -139,6 +135,11 @@ sub checkType
 			$self->checkProp($value, $type, $path, undef, $_changing);
 			return @{ $self->{errors} };
 		}
+		elsif (!$self->jsMatchType($type, $value))
+		{
+			$addError->($self->jsGuessType($value)." value found, but a $type is required");
+			return @E;
+		}
 	}
 	return;
 }
@@ -494,11 +495,12 @@ sub jsMatchType
 	
 	if (lc $type eq 'boolean')
 	{
-		return TRUE if (ref $value eq 'SCALAR' and $$value==0 || $$value==1);
-		return TRUE if ($value eq TRUE);
-		return TRUE if ($value eq FALSE);
-		return TRUE if (ref $value eq 'JSON::PP::Boolean');
-		return TRUE if (ref $value eq 'JSON::XS::Boolean');
+		return FALSE if (ref $value eq 'JSON::Schema::Null');
+		return TRUE  if (ref $value eq 'SCALAR' and $$value==0 || $$value==1);
+		return TRUE  if ($value eq TRUE);
+		return TRUE  if ($value eq FALSE);
+		return TRUE  if (ref $value eq 'JSON::PP::Boolean');
+		return TRUE  if (ref $value eq 'JSON::XS::Boolean');
 		return FALSE;
 	}
 
@@ -590,7 +592,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 Copyright 2007-2009 Kris Zyp.
 
-Copyright 2010-2011 Toby Inkster.
+Copyright 2010-2012 Toby Inkster.
 
 This module is tri-licensed. It is available under the X11 (a.k.a. MIT)
 licence; you can also redistribute it and/or modify it under the same
